# io.swagger.client - Kotlin client library for DiscoverSnoop

## Requires

* Kotlin 1.4.30
* Gradle 5.3

## Build

First, create the gradle wrapper script:

```
gradle wrapper
```

Then, run:

```
./gradlew check assemble
```

This runs all tests and packages the library.

## Features/Implementation Notes

* Supports JSON inputs/outputs, File inputs, and Form inputs.
* Supports collection formats for query parameters: csv, tsv, ssv, pipes.
* Some Kotlin and Java types are fully qualified to avoid conflicts with types defined in Swagger definitions.
* Implementation of ApiClient is intended to reduce method counts, specifically to benefit Android targets.

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://api.discoversnoop.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AlertsApi* | [**alertsChangeGet**](docs/AlertsApi.md#alertschangeget) | **GET** /alerts_change | Edit or insert new alert
*AlertsApi* | [**alertsDeleteGet**](docs/AlertsApi.md#alertsdeleteget) | **GET** /alerts_delete | Permanently delete the alert
*AlertsApi* | [**alertsGet**](docs/AlertsApi.md#alertsget) | **GET** /alerts | Get alerts for user account
*FavsApi* | [**favsAddGet**](docs/FavsApi.md#favsaddget) | **GET** /favs_add | Create a new fav
*FavsApi* | [**favsDeleteGet**](docs/FavsApi.md#favsdeleteget) | **GET** /favs_delete | Permanently delete the fav
*FavsApi* | [**favsGet**](docs/FavsApi.md#favsget) | **GET** /favs | Get favorites
*FavsApi* | [**favsUpdateGet**](docs/FavsApi.md#favsupdateget) | **GET** /favs_update | Update the fav
*HistoricalApi* | [**categoriesGet**](docs/HistoricalApi.md#categoriesget) | **GET** /categories | Get historical stats for categories
*HistoricalApi* | [**categoryGet**](docs/HistoricalApi.md#categoryget) | **GET** /category | Get history for category ID
*HistoricalApi* | [**domainGet**](docs/HistoricalApi.md#domainget) | **GET** /domain | Get history for domain name
*HistoricalApi* | [**domainsGet**](docs/HistoricalApi.md#domainsget) | **GET** /domains | Get historical stats for domains
*HistoricalApi* | [**pageGet**](docs/HistoricalApi.md#pageget) | **GET** /page | Get page history for URL
*HistoricalApi* | [**pagesGet**](docs/HistoricalApi.md#pagesget) | **GET** /pages | Get historical stats for pages
*KbApi* | [**kbArticlesGet**](docs/KbApi.md#kbarticlesget) | **GET** /kb_articles | Get knowledge base articles
*LiveApi* | [**livecategoriesGet**](docs/LiveApi.md#livecategoriesget) | **GET** /livecategories | Get livedata stats for categories
*LiveApi* | [**livedomainsGet**](docs/LiveApi.md#livedomainsget) | **GET** /livedomains | Get livedata stats for domains
*LiveApi* | [**livepagesGet**](docs/LiveApi.md#livepagesget) | **GET** /livepages | Get livedata stats for pages
*UserApi* | [**userCountriesChangeGet**](docs/UserApi.md#usercountrieschangeget) | **GET** /user_countries_change | Change user's activated countries
*UserApi* | [**userCustidChangeGet**](docs/UserApi.md#usercustidchangeget) | **GET** /user_custid_change | Change user customer id. This function is system reserved
*UserApi* | [**userDeleteGet**](docs/UserApi.md#userdeleteget) | **GET** /user_delete | Permanently delete the user
*UserApi* | [**userDetailsChangeGet**](docs/UserApi.md#userdetailschangeget) | **GET** /user_details_change | Change user details
*UserApi* | [**userLoginGet**](docs/UserApi.md#userloginget) | **GET** /user_login | Login user with his credentials
*UserApi* | [**userMessagesGet**](docs/UserApi.md#usermessagesget) | **GET** /user_messages | Get messages for user
*UserApi* | [**userPasswordChangeGet**](docs/UserApi.md#userpasswordchangeget) | **GET** /user_password_change | Change user password
*UserApi* | [**userPasswordResetGet**](docs/UserApi.md#userpasswordresetget) | **GET** /user_password_reset | Reset user password
*UserApi* | [**userRefreshSubscriptionGet**](docs/UserApi.md#userrefreshsubscriptionget) | **GET** /user_refresh_subscription | Refresh user rights with his Customer ID. This function is system reserved
*UserApi* | [**userRegisterGet**](docs/UserApi.md#userregisterget) | **GET** /user_register | Login user with his credentials

<a name="documentation-for-models"></a>
## Documentation for Models

 - [io.swagger.client.models.AlertCollection](docs/AlertCollection.md)
 - [io.swagger.client.models.Alerts](docs/Alerts.md)
 - [io.swagger.client.models.Categories](docs/Categories.md)
 - [io.swagger.client.models.CategoriesCollection](docs/CategoriesCollection.md)
 - [io.swagger.client.models.Category](docs/Category.md)
 - [io.swagger.client.models.DistributionCollection](docs/DistributionCollection.md)
 - [io.swagger.client.models.Domain](docs/Domain.md)
 - [io.swagger.client.models.Domains](docs/Domains.md)
 - [io.swagger.client.models.DomainsCollection](docs/DomainsCollection.md)
 - [io.swagger.client.models.Favs](docs/Favs.md)
 - [io.swagger.client.models.FavsCollection](docs/FavsCollection.md)
 - [io.swagger.client.models.HistoryCollection](docs/HistoryCollection.md)
 - [io.swagger.client.models.KB](docs/KB.md)
 - [io.swagger.client.models.KBCollection](docs/KBCollection.md)
 - [io.swagger.client.models.Message](docs/Message.md)
 - [io.swagger.client.models.MessageCollection](docs/MessageCollection.md)
 - [io.swagger.client.models.MetricsCollection](docs/MetricsCollection.md)
 - [io.swagger.client.models.Page](docs/Page.md)
 - [io.swagger.client.models.Pages](docs/Pages.md)
 - [io.swagger.client.models.PagesCollection](docs/PagesCollection.md)
 - [io.swagger.client.models.TransactionInfo](docs/TransactionInfo.md)
 - [io.swagger.client.models.UserCollection](docs/UserCollection.md)
 - [io.swagger.client.models.UserInfo](docs/UserInfo.md)

<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="bearerAuth"></a>
### bearerAuth


