# HistoricalApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**categoriesGet**](HistoricalApi.md#categoriesGet) | **GET** /categories | Get historical stats for categories
[**categoryGet**](HistoricalApi.md#categoryGet) | **GET** /category | Get history for category ID
[**domainGet**](HistoricalApi.md#domainGet) | **GET** /domain | Get history for domain name
[**domainsGet**](HistoricalApi.md#domainsGet) | **GET** /domains | Get historical stats for domains
[**pageGet**](HistoricalApi.md#pageGet) | **GET** /page | Get page history for URL
[**pagesGet**](HistoricalApi.md#pagesGet) | **GET** /pages | Get historical stats for pages

<a name="categoriesGet"></a>
# **categoriesGet**
> kotlin.Array&lt;Categories&gt; categoriesGet(country, subcountry, fromDate, toDate, keywordFilter, lines, offset)

Get historical stats for categories

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = HistoricalApi()
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val fromDate : kotlin.String = fromDate_example // kotlin.String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
val toDate : kotlin.String = toDate_example // kotlin.String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
val keywordFilter : kotlin.String = keywordFilter_example // kotlin.String | Filter answers to cateogry names containing a particular keyword
val lines : kotlin.Int = 56 // kotlin.Int | Get X results (max in one request is 10K please use offset paginated results if you need more)
val offset : kotlin.Int = 56 // kotlin.Int | Get paginated results from X offset
try {
    val result : kotlin.Array<Categories> = apiInstance.categoriesGet(country, subcountry, fromDate, toDate, keywordFilter, lines, offset)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling HistoricalApi#categoriesGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling HistoricalApi#categoriesGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **subcountry** | **kotlin.String**| state code | [optional]
 **fromDate** | **kotlin.String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **kotlin.String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **keywordFilter** | **kotlin.String**| Filter answers to cateogry names containing a particular keyword | [optional]
 **lines** | **kotlin.Int**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **kotlin.Int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**kotlin.Array&lt;Categories&gt;**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="categoryGet"></a>
# **categoryGet**
> kotlin.Array&lt;Category&gt; categoryGet(id, country, subcountry, fromDate, toDate)

Get history for category ID

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = HistoricalApi()
val id : kotlin.String = id_example // kotlin.String | category id
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val fromDate : kotlin.String = fromDate_example // kotlin.String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
val toDate : kotlin.String = toDate_example // kotlin.String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
try {
    val result : kotlin.Array<Category> = apiInstance.categoryGet(id, country, subcountry, fromDate, toDate)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling HistoricalApi#categoryGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling HistoricalApi#categoryGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| category id |
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **subcountry** | **kotlin.String**| state code | [optional]
 **fromDate** | **kotlin.String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **kotlin.String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]

### Return type

[**kotlin.Array&lt;Category&gt;**](Category.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="domainGet"></a>
# **domainGet**
> kotlin.Array&lt;Domain&gt; domainGet(domain, country, subcountry, fromDate, toDate)

Get history for domain name

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = HistoricalApi()
val domain : kotlin.String = domain_example // kotlin.String | domain name (no subdomain allowed)
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val fromDate : kotlin.String = fromDate_example // kotlin.String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
val toDate : kotlin.String = toDate_example // kotlin.String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
try {
    val result : kotlin.Array<Domain> = apiInstance.domainGet(domain, country, subcountry, fromDate, toDate)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling HistoricalApi#domainGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling HistoricalApi#domainGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **domain** | **kotlin.String**| domain name (no subdomain allowed) |
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **subcountry** | **kotlin.String**| state code | [optional]
 **fromDate** | **kotlin.String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **kotlin.String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]

### Return type

[**kotlin.Array&lt;Domain&gt;**](Domain.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="domainsGet"></a>
# **domainsGet**
> kotlin.Array&lt;Domains&gt; domainsGet(country, subcountry, fromDate, toDate, urlFilter, lines, offset)

Get historical stats for domains

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = HistoricalApi()
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val fromDate : kotlin.String = fromDate_example // kotlin.String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
val toDate : kotlin.String = toDate_example // kotlin.String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
val urlFilter : kotlin.String = urlFilter_example // kotlin.String | Filter answers to domains including a specified string
val lines : kotlin.Int = 56 // kotlin.Int | Get X results (max in one request is 10K please use offset paginated results if you need more)
val offset : kotlin.Int = 56 // kotlin.Int | Get paginated results from X offset
try {
    val result : kotlin.Array<Domains> = apiInstance.domainsGet(country, subcountry, fromDate, toDate, urlFilter, lines, offset)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling HistoricalApi#domainsGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling HistoricalApi#domainsGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **subcountry** | **kotlin.String**| state code | [optional]
 **fromDate** | **kotlin.String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **kotlin.String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **urlFilter** | **kotlin.String**| Filter answers to domains including a specified string | [optional]
 **lines** | **kotlin.Int**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **kotlin.Int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**kotlin.Array&lt;Domains&gt;**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pageGet"></a>
# **pageGet**
> kotlin.Array&lt;Page&gt; pageGet(url, country, subcountry, fromDate, toDate)

Get page history for URL

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = HistoricalApi()
val url : kotlin.String = url_example // kotlin.String | Fully qualified page url. URL needs to be URL encoded
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val fromDate : kotlin.String = fromDate_example // kotlin.String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
val toDate : kotlin.String = toDate_example // kotlin.String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
try {
    val result : kotlin.Array<Page> = apiInstance.pageGet(url, country, subcountry, fromDate, toDate)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling HistoricalApi#pageGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling HistoricalApi#pageGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **kotlin.String**| Fully qualified page url. URL needs to be URL encoded |
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **subcountry** | **kotlin.String**| state code | [optional]
 **fromDate** | **kotlin.String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **kotlin.String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]

### Return type

[**kotlin.Array&lt;Page&gt;**](Page.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pagesGet"></a>
# **pagesGet**
> kotlin.Array&lt;Pages&gt; pagesGet(presetFilter, fromDate, toDate, country, subcountry, domainFilter, urlFilter, categoryFilter, keywordFilter, lines, offset)

Get historical stats for pages

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = HistoricalApi()
val presetFilter : kotlin.Int = 56 // kotlin.Int | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
val fromDate : kotlin.String = fromDate_example // kotlin.String | Datas from YYYY-MM-DD (if not provided, last 30 days)
val toDate : kotlin.String = toDate_example // kotlin.String | Datas to YYYY-MM-DD (if not provided, last 30 days)
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters (if not provided  worldwide)
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val domainFilter : kotlin.String = domainFilter_example // kotlin.String | Filter answers to pages of a designated domain name
val urlFilter : kotlin.String = urlFilter_example // kotlin.String | Filter answers to pages URL including a specified string
val categoryFilter : kotlin.Int = 56 // kotlin.Int | Filter answers to a specific page category
val keywordFilter : kotlin.String = keywordFilter_example // kotlin.String | Filter answers to pages titles containing a particular keyword
val lines : kotlin.Int = 56 // kotlin.Int | Get X results (max in one request is 50 please use offset paginated results if you need more)
val offset : kotlin.Int = 56 // kotlin.Int | Get paginated results from X offset
try {
    val result : kotlin.Array<Pages> = apiInstance.pagesGet(presetFilter, fromDate, toDate, country, subcountry, domainFilter, urlFilter, categoryFilter, keywordFilter, lines, offset)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling HistoricalApi#pagesGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling HistoricalApi#pagesGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **presetFilter** | **kotlin.Int**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone |
 **fromDate** | **kotlin.String**| Datas from YYYY-MM-DD (if not provided, last 30 days) | [optional]
 **toDate** | **kotlin.String**| Datas to YYYY-MM-DD (if not provided, last 30 days) | [optional]
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters (if not provided  worldwide) | [optional]
 **subcountry** | **kotlin.String**| state code | [optional]
 **domainFilter** | **kotlin.String**| Filter answers to pages of a designated domain name | [optional]
 **urlFilter** | **kotlin.String**| Filter answers to pages URL including a specified string | [optional]
 **categoryFilter** | **kotlin.Int**| Filter answers to a specific page category | [optional]
 **keywordFilter** | **kotlin.String**| Filter answers to pages titles containing a particular keyword | [optional]
 **lines** | **kotlin.Int**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **kotlin.Int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**kotlin.Array&lt;Pages&gt;**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

