# LiveApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**livecategoriesGet**](LiveApi.md#livecategoriesGet) | **GET** /livecategories | Get livedata stats for categories
[**livedomainsGet**](LiveApi.md#livedomainsGet) | **GET** /livedomains | Get livedata stats for domains
[**livepagesGet**](LiveApi.md#livepagesGet) | **GET** /livepages | Get livedata stats for pages

<a name="livecategoriesGet"></a>
# **livecategoriesGet**
> kotlin.Array&lt;Categories&gt; livecategoriesGet(country, subcountry, hours, keywordFilter, languageFilter, lines, offset)

Get livedata stats for categories

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = LiveApi()
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val hours : kotlin.Int = 56 // kotlin.Int | Get results for last x hours
val keywordFilter : kotlin.String = keywordFilter_example // kotlin.String | Filter answers to category names containing a particular keyword
val languageFilter : kotlin.String = languageFilter_example // kotlin.String | Filter answers to pages in specific user language
val lines : kotlin.Int = 56 // kotlin.Int | Get X results (max in one request is 10K please use offset paginated results if you need more)
val offset : kotlin.Int = 56 // kotlin.Int | Get paginated results from X offset
try {
    val result : kotlin.Array<Categories> = apiInstance.livecategoriesGet(country, subcountry, hours, keywordFilter, languageFilter, lines, offset)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling LiveApi#livecategoriesGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling LiveApi#livecategoriesGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **subcountry** | **kotlin.String**| state code | [optional]
 **hours** | **kotlin.Int**| Get results for last x hours | [optional]
 **keywordFilter** | **kotlin.String**| Filter answers to category names containing a particular keyword | [optional]
 **languageFilter** | **kotlin.String**| Filter answers to pages in specific user language | [optional]
 **lines** | **kotlin.Int**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **kotlin.Int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**kotlin.Array&lt;Categories&gt;**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="livedomainsGet"></a>
# **livedomainsGet**
> kotlin.Array&lt;Domains&gt; livedomainsGet(country, subcountry, urlFilter, hours, lines, languageFilter, offset)

Get livedata stats for domains

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = LiveApi()
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val urlFilter : kotlin.String = urlFilter_example // kotlin.String | Filter answers to domains including a specified string
val hours : kotlin.Int = 56 // kotlin.Int | Get results for last x hours
val lines : kotlin.Int = 56 // kotlin.Int | Get X results (max in one request is 10K please use offset paginated results if you need more)
val languageFilter : kotlin.String = languageFilter_example // kotlin.String | Filter answers to pages in specific user language
val offset : kotlin.Int = 56 // kotlin.Int | Get paginated results from X offset
try {
    val result : kotlin.Array<Domains> = apiInstance.livedomainsGet(country, subcountry, urlFilter, hours, lines, languageFilter, offset)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling LiveApi#livedomainsGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling LiveApi#livedomainsGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **subcountry** | **kotlin.String**| state code | [optional]
 **urlFilter** | **kotlin.String**| Filter answers to domains including a specified string | [optional]
 **hours** | **kotlin.Int**| Get results for last x hours | [optional]
 **lines** | **kotlin.Int**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **languageFilter** | **kotlin.String**| Filter answers to pages in specific user language | [optional]
 **offset** | **kotlin.Int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**kotlin.Array&lt;Domains&gt;**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="livepagesGet"></a>
# **livepagesGet**
> kotlin.Array&lt;Pages&gt; livepagesGet(country, presetFilter, subcountry, hours, onlyNew, domainFilter, keywordFilter, urlFilter, categoryFilter, languageFilter, lines, offset)

Get livedata stats for pages

### Example
```kotlin
// Import classes:
//import io.swagger.client.infrastructure.*
//import io.swagger.client.models.*;

val apiInstance = LiveApi()
val country : kotlin.String = country_example // kotlin.String | ISO_3166 country code in 2 letters
val presetFilter : kotlin.Int = 56 // kotlin.Int | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
val subcountry : kotlin.String = subcountry_example // kotlin.String | state code
val hours : kotlin.Int = 56 // kotlin.Int | Get results for last x hours
val onlyNew : kotlin.Int = 56 // kotlin.Int | Get only pages first seen in the reporting period if set on 1
val domainFilter : kotlin.String = domainFilter_example // kotlin.String | Filter answers to pages of a designated domain name
val keywordFilter : kotlin.String = keywordFilter_example // kotlin.String | Filter answers to pages titles containing a particular keyword
val urlFilter : kotlin.String = urlFilter_example // kotlin.String | Filter answers to pages URL including a specified string
val categoryFilter : kotlin.Int = 56 // kotlin.Int | Filter answers to pages of a designated category id
val languageFilter : kotlin.String = languageFilter_example // kotlin.String | Filter answers to pages in specific user language
val lines : kotlin.Int = 56 // kotlin.Int | Get X results (max in one request is 50 please use offset paginated results if you need more)
val offset : kotlin.Int = 56 // kotlin.Int | Get paginated results from X offset
try {
    val result : kotlin.Array<Pages> = apiInstance.livepagesGet(country, presetFilter, subcountry, hours, onlyNew, domainFilter, keywordFilter, urlFilter, categoryFilter, languageFilter, lines, offset)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling LiveApi#livepagesGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling LiveApi#livepagesGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **kotlin.String**| ISO_3166 country code in 2 letters |
 **presetFilter** | **kotlin.Int**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone |
 **subcountry** | **kotlin.String**| state code | [optional]
 **hours** | **kotlin.Int**| Get results for last x hours | [optional]
 **onlyNew** | **kotlin.Int**| Get only pages first seen in the reporting period if set on 1 | [optional] [default to 0]
 **domainFilter** | **kotlin.String**| Filter answers to pages of a designated domain name | [optional]
 **keywordFilter** | **kotlin.String**| Filter answers to pages titles containing a particular keyword | [optional]
 **urlFilter** | **kotlin.String**| Filter answers to pages URL including a specified string | [optional]
 **categoryFilter** | **kotlin.Int**| Filter answers to pages of a designated category id | [optional]
 **languageFilter** | **kotlin.String**| Filter answers to pages in specific user language | [optional]
 **lines** | **kotlin.Int**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **kotlin.Int**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**kotlin.Array&lt;Pages&gt;**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

